@@ -9,18 +9,24 @@ from html import escape
 import pytest_html
 import re
 import minizinc as mzn
-import datetime
-from minizinc.helpers import check_solution
 from difflib import HtmlDiff
-import warnings
 import sys
 
 
+def pytest_configure(config):
+    pytest.solver_cache = {}
+    search = config.getoption("--driver")
+    if search is not None:
+        driver = mzn.find_driver([search])
+        if driver is None:
+            raise Exception("Failed to find MiniZinc driver in {}".format(search))
+        driver.make_default()
+
+
 def pytest_addoption(parser):
     parser.addoption(
         "--solvers",
         action="store",
-        default="gecode,cbc,chuffed",
         metavar="SOLVERS",
         help="only run tests with the comma separated SOLVERS.",
     )
@@ -29,19 +35,22 @@ def pytest_addoption(parser):
         action="append",
         default=[],
         metavar="SUITE_NAME",
-        help="Use the given YAML configuration from suites.yml"
+        help="Use the given YAML configuration from suites.yml",
     )
     parser.addoption(
-        "--all-suites",
-        action="store_true",
-        dest="feature",
-        help="Run all test suites"
+        "--all-suites", action="store_true", dest="feature", help="Run all test suites"
+    )
+    parser.addoption(
+        "--driver",
+        action="store",
+        metavar="MINIZINC",
+        help="Directory containing MiniZinc executable",
     )
 
 
 def pytest_collect_file(parent, path):
     if path.ext == ".mzn":
-        return MznFile(path, parent)
+        return MznFile.from_parent(parent, fspath=path)
 
 
 def pytest_html_results_table_header(cells):
@@ -70,7 +79,9 @@ def pytest_runtest_makereport(item, call):
             html_content = """
                 <button class="copy-button" onclick="this.nextElementSibling.select();document.execCommand('copy');this.textContent = 'Copied!';">Copy obtained output to clipboard</button>
                 <textarea class="hidden-textarea" readonly>{}</textarea>
-            """.format(escape(obtained))
+            """.format(
+                escape(obtained)
+            )
             actual = obtained.split("\n")
             htmldiff = HtmlDiff(2)
             html_content += '<h4>Diffs</h4><div class="diffs">'
@@ -113,7 +124,9 @@ class MznFile(pytest.File):
             contents = file.read()
             yaml_comment = re.match(r"\/\*\*\*\n(.*?)\n\*\*\*\/", contents, flags=re.S)
             if yaml_comment is None:
-                pytest.skip("skipping {} as no tests specified".format(str(self.fspath)))
+                pytest.skip(
+                    "skipping {} as no tests specified".format(str(self.fspath))
+                )
             else:
                 tests = [doc for doc in yaml.load_all(yaml_comment.group(1))]
 
@@ -121,20 +134,29 @@ class MznFile(pytest.File):
                     if any(self.fspath.fnmatch(glob) for glob in suite.includes):
                         for i, spec in enumerate(tests):
                             for solver in spec.solvers:
-                                base = str(i) if spec.name is yaml.Undefined else spec.name
+                                base = (
+                                    str(i) if spec.name is yaml.Undefined else spec.name
+                                )
                                 name = "{}.{}.{}".format(suite_name, base, solver)
                                 cache = CachedResult()
-                                yield SolveItem(name, self, spec, solver, cache, spec.markers, suite)
-
+                                yield SolveItem.from_parent(
+                                    self,
+                                    name=name,
+                                    spec=spec,
+                                    solver=solver,
+                                    cache=cache,
+                                    markers=spec.markers,
+                                    suite=suite,
+                                )
                                 for checker in spec.check_against:
-                                    yield CheckItem(
-                                        "{}:{}".format(name, checker),
+                                    yield CheckItem.from_parent(
                                         self,
-                                        cache,
-                                        solver,
-                                        checker,
-                                        spec.markers,
-                                        suite,
+                                        name="{}:{}".format(name, checker),
+                                        cache=cache,
+                                        solver=solver,
+                                        checker=checker,
+                                        markers=spec.markers,
+                                        suite=suite,
                                     )
 
 
@@ -145,13 +167,41 @@ class MznItem(pytest.Item):
         for marker in markers:
             self.add_marker(marker)
 
-        allowed = [x.strip() for x in self.config.getoption("--solvers").split(",")]
-        allowed = [x for x in allowed if x in suite.solvers]
-        if solver not in allowed:
+        if self.config.getoption("--solvers") is not None:
+            self.allowed = [
+                x.strip() for x in self.config.getoption("--solvers").split(",")
+            ]
+            self.allowed = [x for x in self.allowed if x in suite.solvers]
+        else:
+            self.allowed = suite.solvers
+
+        if not self.solver_allowed(solver):
             self.add_marker(
-                pytest.mark.skip("skipping {} not in {}".format(solver, allowed))
+                pytest.mark.skip("skipping {} not in {}".format(solver, self.allowed))
             )
 
+        if not self.solver_exists(solver):
+            self.add_marker(pytest.mark.skip("Solver {} not available".format(solver)))
+
+    def solver_allowed(self, solver):
+        return self.allowed is None or solver in self.allowed
+
+    def solver_exists(self, solver):
+        solver_exists = pytest.solver_cache.get(solver, None)
+        if solver_exists is None:
+            try:
+                s = mzn.Solver.lookup(solver)
+                empty_model = mzn.Model()
+                empty_model.add_string("solve satisfy;")
+                instance = mzn.Instance(s, empty_model)
+                instance.solve()
+                solver_exists = True
+            except (mzn.MiniZincError, LookupError) as error:
+                solver_exists = False
+            finally:
+                pytest.solver_cache[solver] = solver_exists
+        return solver_exists
+
 
 class SolveItem(MznItem):
     def __init__(self, name, parent, spec, solver, cache, markers, suite):
@@ -191,11 +241,11 @@ class SolveItem(MznItem):
                     non_strict_pass = self.cache.test(checker)
                     status = "but passed" if non_strict_pass else "and failed"
                     message += "\n\n{} check against {}.".format(status, checker)
-                    
+
                     if not self.strict and non_strict_pass:
                         print(message, file=sys.stderr)
                         return
-                        
+
             assert False, message
 
     def reportinfo(self):
@@ -205,11 +255,15 @@ class SolveItem(MznItem):
 class CheckItem(MznItem):
     def __init__(self, name, parent, cache, solver, checker, markers, suite):
         super().__init__(name, parent, solver, markers, suite)
-        allowed = [x.strip() for x in self.config.getoption("--solvers").split(",")]
-        allowed = [x for x in allowed if x in suite.solvers]
-        if checker not in allowed:
+        if not self.solver_allowed(checker):
             self.add_marker(
-                pytest.mark.skip("skipping checker {} not in {}".format(checker, allowed))
+                pytest.mark.skip(
+                    "skipping checker {} not in {}".format(checker, self.allowed)
+                )
+            )
+        if not self.solver_exists(checker):
+            self.add_marker(
+                pytest.mark.skip("skipping checker {} not available".format(checker))
             )
 
         self.cache = cache
@@ -226,7 +280,9 @@ class CheckItem(MznItem):
             pytest.skip("skipping check for no result/solution")
         else:
             passed = self.cache.test(self.checker)
-            assert passed, "failed when checking against {}. Got {}".format(self.checker, yaml.dump(self.cache.obtained))
+            assert passed, "failed when checking against {}. Got {}".format(
+                self.checker, yaml.dump(self.cache.obtained)
+            )
 
     def reportinfo(self):
         return self.fspath, 0, "{}::{}".format(str(self.fspath), self.name)
